@@ -19,9 +19,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: StarOffice.py 2548 2007-07-21 21:46:43Z wwalker $"
-__version__   = "$Revision: 2548 $"
-__date__      = "$Date: 2007-07-21 17:46:43 -0400 (Sat, 21 Jul 2007) $"
+__id__        = "$Id: StarOffice.py 2719 2007-08-26 18:52:54Z joanied $"
+__version__   = "$Revision: 2719 $"
+__date__      = "$Date: 2007-08-26 14:52:54 -0400 (Sun, 26 Aug 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -45,6 +45,7 @@ import orca.keybindings as keybindings
 import orca.where_am_I as where_am_I
 
 from orca.orca_i18n import _ # for gettext support
+from orca_i18n import Q_     # to provide qualified translatable strings
 
 # Whether we speak spread sheet cell coordinates as the user moves around.
 #
@@ -136,7 +137,9 @@ class WhereAmI(where_am_I.WhereAmI):
             # Translators: when the user selects (highlights) text in
             # a document, Orca lets them know this.
             #
-            text = _("selected")
+            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+            #
+            text = Q_("text|selected")
             utterances.append(text)
 
         debug.println(self._debugLevel, "editable table cell utterances=%s" % \
